@@ -18,34 +18,34 @@ from sahara.plugins import provisioning as p
 from sahara.utils import files as f
 
 
-class ConfigHelperV570(c_h.ConfigHelper):
-    path_to_config = 'plugins/cdh/v5_7_0/resources/'
+class ConfigHelperV5110(c_h.ConfigHelper):
+    path_to_config = 'plugins/cdh/v5_11_0/resources/'
 
     CDH5_UBUNTU_REPO = (
         'deb [arch=amd64] http://archive.cloudera.com/cdh5'
-        '/ubuntu/trusty/amd64/cdh trusty-cdh5.7.0 contrib'
+        '/ubuntu/xenial/amd64/cdh trusty-cdh5.11.0 contrib'
         '\ndeb-src http://archive.cloudera.com/cdh5/ubuntu'
-        '/trusty/amd64/cdh trusty-cdh5.7.0 contrib')
+        '/xenial/amd64/cdh trusty-cdh5.11.0 contrib')
 
     DEFAULT_CDH5_UBUNTU_REPO_KEY_URL = (
         'http://archive.cloudera.com/cdh5/ubuntu'
-        '/trusty/amd64/cdh/archive.key')
+        '/xenial/amd64/cdh/archive.key')
 
     CM5_UBUNTU_REPO = (
         'deb [arch=amd64] http://archive.cloudera.com/cm5'
-        '/ubuntu/trusty/amd64/cm trusty-cm5.7.0 contrib'
+        '/ubuntu/xenial/amd64/cm trusty-cm5.11.0 contrib'
         '\ndeb-src http://archive.cloudera.com/cm5/ubuntu'
-        '/trusty/amd64/cm trusty-cm5.7.0 contrib')
+        '/xenial/amd64/cm trusty-cm5.11.0 contrib')
 
     DEFAULT_CM5_UBUNTU_REPO_KEY_URL = (
         'http://archive.cloudera.com/cm5/ubuntu'
-        '/trusty/amd64/cm/archive.key')
+        '/xenial/amd64/cm/archive.key')
 
     CDH5_CENTOS_REPO = (
         '[cloudera-cdh5]'
         '\nname=Cloudera\'s Distribution for Hadoop, Version 5'
         '\nbaseurl=http://archive.cloudera.com/cdh5/redhat/6'
-        '/x86_64/cdh/5.7.0/'
+        '/x86_64/cdh/5.11.0/'
         '\ngpgkey = http://archive.cloudera.com/cdh5/redhat/6'
         '/x86_64/cdh/RPM-GPG-KEY-cloudera'
         '\ngpgcheck = 1')
@@ -54,19 +54,19 @@ class ConfigHelperV570(c_h.ConfigHelper):
         '[cloudera-manager]'
         '\nname=Cloudera Manager'
         '\nbaseurl=http://archive.cloudera.com/cm5/redhat/6'
-        '/x86_64/cm/5.7.0/'
+        '/x86_64/cm/5.11.0/'
         '\ngpgkey = http://archive.cloudera.com/cm5/redhat/6'
         '/x86_64/cm/RPM-GPG-KEY-cloudera'
         '\ngpgcheck = 1')
 
     KEY_TRUSTEE_UBUNTU_REPO_URL = (
         'http://archive.cloudera.com/navigator-'
-        'keytrustee5/ubuntu/trusty/amd64/navigator-'
+        'keytrustee5/ubuntu/xenial/amd64/navigator-'
         'keytrustee/cloudera.list')
 
     DEFAULT_KEY_TRUSTEE_UBUNTU_REPO_KEY_URL = (
         'http://archive.cloudera.com/navigator-'
-        'keytrustee5/ubuntu/trusty/amd64/navigator-'
+        'keytrustee5/ubuntu/xenial/amd64/navigator-'
         'keytrustee/archive.key')
 
     KEY_TRUSTEE_CENTOS_REPO_URL = (
@@ -76,8 +76,8 @@ class ConfigHelperV570(c_h.ConfigHelper):
 
     DEFAULT_SWIFT_LIB_URL = (
         'https://repository.cloudera.com/artifactory/repo/org'
-        '/apache/hadoop/hadoop-openstack/2.6.0-cdh5.7.0'
-        '/hadoop-openstack-2.6.0-cdh5.7.0.jar')
+        '/apache/hadoop/hadoop-openstack/2.6.0-cdh5.11.0'
+        '/hadoop-openstack-2.6.0-cdh5.11.0.jar')
 
     SWIFT_LIB_URL = p.Config(
         'Hadoop OpenStack library URL', 'general', 'cluster', priority=1,
@@ -95,7 +95,7 @@ class ConfigHelperV570(c_h.ConfigHelper):
         path_to_config + 'sentry-impala-client-safety.xml')
 
     def __init__(self):
-        super(ConfigHelperV570, self).__init__()
+        super(ConfigHelperV5110, self).__init__()
         self.priority_one_confs = self._load_json(
             self.path_to_config + 'priority-one-confs.json')
         self._init_all_ng_plugin_configs()
