@@ -20,19 +20,21 @@ from sahara.plugins.mapr.services.hbase import hbase
 from sahara.plugins.mapr.services.hive import hive
 from sahara.plugins.mapr.services.httpfs import httpfs
 from sahara.plugins.mapr.services.hue import hue
+from sahara.plugins.mapr.services.impala import impala
+from sahara.plugins.mapr.services.kafka import kafka
 from sahara.plugins.mapr.services.mahout import mahout
 from sahara.plugins.mapr.services.management import management as mng
 from sahara.plugins.mapr.services.maprfs import maprfs
 from sahara.plugins.mapr.services.oozie import oozie
 from sahara.plugins.mapr.services.pig import pig
+from sahara.plugins.mapr.services.sentry import sentry
 from sahara.plugins.mapr.services.spark import spark
 from sahara.plugins.mapr.services.sqoop import sqoop2
 from sahara.plugins.mapr.services.swift import swift
 from sahara.plugins.mapr.services.yarn import yarn
-import sahara.plugins.mapr.versions.v5_1_0_mrv2.context as c
+import sahara.plugins.mapr.versions.v5_2_0_mrv2.context as c
 
-
-version = "5.1.0.mrv2"
+version = "5.2.0.mrv2"
 
 
 class VersionHandler(bvh.BaseVersionHandler):
@@ -46,28 +48,27 @@ class VersionHandler(bvh.BaseVersionHandler):
             oozie.Oozie(),
         ]
         self._services = [
-            hive.HiveV013(),
             hive.HiveV12(),
-            pig.PigV014(),
-            pig.PigV015(),
+            pig.PigV016(),
+            impala.ImpalaV250(),
             flume.FlumeV16(),
-            flume.FlumeV15(),
             sqoop2.Sqoop2(),
-            mahout.MahoutV010(),
-            oozie.OozieV410(),
+            mahout.MahoutV012(),
             oozie.OozieV420(),
-            hue.HueV381(),
-            hue.HueV390(),
-            hbase.HBaseV09812(),
-            drill.DrillV11(),
-            drill.DrillV12(),
-            drill.DrillV14(),
+            hue.HueV310(),
+            hue.HueLivyV310(),
+            hbase.HBaseV111(),
+            drill.DrillV19(),
             yarn.YARNv270(),
             maprfs.MapRFS(),
             mng.Management(),
             httpfs.HttpFS(),
             swift.Swift(),
-            spark.SparkOnYarn()
+            sentry.SentryV16(),
+            spark.SparkOnYarnV201(),
+            kafka.Kafka(),
+            kafka.KafkaConnect(),
+            kafka.KafkaRest(),
         ]
 
     def get_context(self, cluster, added=None, removed=None):
